terminal

package module
v0.1.0-alpha.42 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 16, 2024 License: Apache-2.0 Imports: 11 Imported by: 4

README

Terminal Go API Library

Go Reference

The Terminal Go library provides convenient access to the Terminal REST API from applications written in Go. The full API of this library can be found in api.md.

It is generated with Stainless.

Installation

import (
	"github.com/terminaldotshop/terminal-sdk-go" // imported as terminal
)

Or to pin the version:

go get -u 'github.com/terminaldotshop/terminal-sdk-go@v0.1.0-alpha.42'

Requirements

This library requires Go 1.18+.

Usage

The full API of this library can be found in api.md.

package main

import (
	"context"
	"fmt"

	"github.com/terminaldotshop/terminal-sdk-go"
	"github.com/terminaldotshop/terminal-sdk-go/option"
)

func main() {
	client := terminal.NewClient(
		option.WithBearerToken("My Bearer Token"), // defaults to os.LookupEnv("TERMINAL_BEARER_TOKEN")
		option.WithEnvironmentSandbox(),           // defaults to option.WithEnvironmentProduction()
	)
	product, err := client.Products.List(context.TODO())
	if err != nil {
		panic(err.Error())
	}
	fmt.Printf("%+v\n", product.Data)
}

Request fields

All request parameters are wrapped in a generic Field type, which we use to distinguish zero values from null or omitted fields.

This prevents accidentally sending a zero value if you forget a required parameter, and enables explicitly sending null, false, '', or 0 on optional parameters. Any field not specified is not sent.

To construct fields with values, use the helpers String(), Int(), Float(), or most commonly, the generic F[T](). To send a null, use Null[T](), and to send a nonconforming value, use Raw[T](any). For example:

params := FooParams{
	Name: terminal.F("hello"),

	// Explicitly send `"description": null`
	Description: terminal.Null[string](),

	Point: terminal.F(terminal.Point{
		X: terminal.Int(0),
		Y: terminal.Int(1),

		// In cases where the API specifies a given type,
		// but you want to send something else, use `Raw`:
		Z: terminal.Raw[int64](0.01), // sends a float
	}),
}
Response objects

All fields in response structs are value types (not pointers or wrappers).

If a given field is null, not present, or invalid, the corresponding field will simply be its zero value.

All response structs also include a special JSON field, containing more detailed information about each property, which you can use like so:

if res.Name == "" {
	// true if `"name"` is either not present or explicitly null
	res.JSON.Name.IsNull()

	// true if the `"name"` key was not present in the repsonse JSON at all
	res.JSON.Name.IsMissing()

	// When the API returns data that cannot be coerced to the expected type:
	if res.JSON.Name.IsInvalid() {
		raw := res.JSON.Name.Raw()

		legacyName := struct{
			First string `json:"first"`
			Last  string `json:"last"`
		}{}
		json.Unmarshal([]byte(raw), &legacyName)
		name = legacyName.First + " " + legacyName.Last
	}
}

These .JSON structs also include an Extras map containing any properties in the json response that were not specified in the struct. This can be useful for API features not yet present in the SDK.

body := res.JSON.ExtraFields["my_unexpected_field"].Raw()
RequestOptions

This library uses the functional options pattern. Functions defined in the option package return a RequestOption, which is a closure that mutates a RequestConfig. These options can be supplied to the client or at individual requests. For example:

client := terminal.NewClient(
	// Adds a header to every request made by the client
	option.WithHeader("X-Some-Header", "custom_header_info"),
)

client.Products.List(context.TODO(), ...,
	// Override the header
	option.WithHeader("X-Some-Header", "some_other_custom_header_info"),
	// Add an undocumented field to the request body, using sjson syntax
	option.WithJSONSet("some.json.path", map[string]string{"my": "object"}),
)

See the full list of request options.

Pagination

This library provides some conveniences for working with paginated list endpoints.

You can use .ListAutoPaging() methods to iterate through items across all pages:

Or you can use simple .List() methods to fetch a single page and receive a standard response object with additional helper methods like .GetNextPage(), e.g.:

Errors

When the API returns a non-success status code, we return an error with type *terminal.Error. This contains the StatusCode, *http.Request, and *http.Response values of the request, as well as the JSON of the error body (much like other response objects in the SDK).

To handle errors, we recommend that you use the errors.As pattern:

_, err := client.Products.List(context.TODO())
if err != nil {
	var apierr *terminal.Error
	if errors.As(err, &apierr) {
		println(string(apierr.DumpRequest(true)))  // Prints the serialized HTTP request
		println(string(apierr.DumpResponse(true))) // Prints the serialized HTTP response
	}
	panic(err.Error()) // GET "/products": 400 Bad Request { ... }
}

When other errors occur, they are returned unwrapped; for example, if HTTP transport fails, you might receive *url.Error wrapping *net.OpError.

Timeouts

Requests do not time out by default; use context to configure a timeout for a request lifecycle.

Note that if a request is retried, the context timeout does not start over. To set a per-retry timeout, use option.WithRequestTimeout().

// This sets the timeout for the request, including all the retries.
ctx, cancel := context.WithTimeout(context.Background(), 5*time.Minute)
defer cancel()
client.Products.List(
	ctx,
	// This sets the per-retry timeout
	option.WithRequestTimeout(20*time.Second),
)
File uploads

Request parameters that correspond to file uploads in multipart requests are typed as param.Field[io.Reader]. The contents of the io.Reader will by default be sent as a multipart form part with the file name of "anonymous_file" and content-type of "application/octet-stream".

The file name and content-type can be customized by implementing Name() string or ContentType() string on the run-time type of io.Reader. Note that os.File implements Name() string, so a file returned by os.Open will be sent with the file name on disk.

We also provide a helper terminal.FileParam(reader io.Reader, filename string, contentType string) which can be used to wrap any io.Reader with the appropriate file name and content type.

Retries

Certain errors will be automatically retried 2 times by default, with a short exponential backoff. We retry by default all connection errors, 408 Request Timeout, 409 Conflict, 429 Rate Limit, and >=500 Internal errors.

You can use the WithMaxRetries option to configure or disable this:

// Configure the default for all requests:
client := terminal.NewClient(
	option.WithMaxRetries(0), // default is 2
)

// Override per-request:
client.Products.List(context.TODO(), option.WithMaxRetries(5))
Making custom/undocumented requests

This library is typed for convenient access to the documented API. If you need to access undocumented endpoints, params, or response properties, the library can still be used.

Undocumented endpoints

To make requests to undocumented endpoints, you can use client.Get, client.Post, and other HTTP verbs. RequestOptions on the client, such as retries, will be respected when making these requests.

var (
    // params can be an io.Reader, a []byte, an encoding/json serializable object,
    // or a "…Params" struct defined in this library.
    params map[string]interface{}

    // result can be an []byte, *http.Response, a encoding/json deserializable object,
    // or a model defined in this library.
    result *http.Response
)
err := client.Post(context.Background(), "/unspecified", params, &result)
if err != nil {
    …
}
Undocumented request params

To make requests using undocumented parameters, you may use either the option.WithQuerySet() or the option.WithJSONSet() methods.

params := FooNewParams{
    ID:   terminal.F("id_xxxx"),
    Data: terminal.F(FooNewParamsData{
        FirstName: terminal.F("John"),
    }),
}
client.Foo.New(context.Background(), params, option.WithJSONSet("data.last_name", "Doe"))
Undocumented response properties

To access undocumented response properties, you may either access the raw JSON of the response as a string with result.JSON.RawJSON(), or get the raw JSON of a particular field on the result with result.JSON.Foo.Raw().

Any fields that are not present on the response struct will be saved and can be accessed by result.JSON.ExtraFields() which returns the extra fields as a map[string]Field.

Middleware

We provide option.WithMiddleware which applies the given middleware to requests.

func Logger(req *http.Request, next option.MiddlewareNext) (res *http.Response, err error) {
	// Before the request
	start := time.Now()
	LogReq(req)

	// Forward the request to the next handler
	res, err = next(req)

	// Handle stuff after the request
	end := time.Now()
	LogRes(res, err, start - end)

    return res, err
}

client := terminal.NewClient(
	option.WithMiddleware(Logger),
)

When multiple middlewares are provided as variadic arguments, the middlewares are applied left to right. If option.WithMiddleware is given multiple times, for example first in the client then the method, the middleware in the client will run first and the middleware given in the method will run next.

You may also replace the default http.Client with option.WithHTTPClient(client). Only one http client is accepted (this overwrites any previous client) and receives requests after any middleware has been applied.

Semantic versioning

This package generally follows SemVer conventions, though certain backwards-incompatible changes may be released as minor versions:

  1. Changes to library internals which are technically public but not intended or documented for external use. (Please open a GitHub issue to let us know if you are relying on such internals).
  2. Changes that we do not expect to impact the vast majority of users in practice.

We take backwards-compatibility seriously and work hard to ensure you can rely on a smooth upgrade experience.

We are keen for your feedback; please open an issue with questions, bugs, or suggestions.

Contributing

See the contributing documentation.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Bool

func Bool(value bool) param.Field[bool]

Bool is a param field helper which helps specify bools.

func F

func F[T any](value T) param.Field[T]

F is a param field helper used to initialize a param.Field generic struct. This helps specify null, zero values, and overrides, as well as normal values. You can read more about this in our README.

func FileParam

func FileParam(reader io.Reader, filename string, contentType string) param.Field[io.Reader]

FileParam is a param field helper which helps files with a mime content-type.

func Float

func Float(value float64) param.Field[float64]

Float is a param field helper which helps specify floats.

func Int

func Int(value int64) param.Field[int64]

Int is a param field helper which helps specify integers. This is particularly helpful when specifying integer constants for fields.

func Null

func Null[T any]() param.Field[T]

Null is a param field helper which explicitly sends null to the API.

func Raw

func Raw[T any](value any) param.Field[T]

Raw is a param field helper for specifying values for fields when the type you are looking to send is different from the type that is specified in the SDK. For example, if the type of the field is an integer, but you want to send a float, you could do that by setting the corresponding field with Raw[int](0.5).

func String

func String(value string) param.Field[string]

String is a param field helper which helps specify strings.

Types

type Address

type Address struct {
	// Unique object identifier. The format and length of IDs may change over time.
	ID string `json:"id,required"`
	// City of the address.
	City string `json:"city,required"`
	// ISO 3166-1 alpha-2 country code of the address.
	Country string `json:"country,required"`
	// The recipient's name.
	Name string `json:"name,required"`
	// Street of the address.
	Street1 string `json:"street1,required"`
	// Zip code of the address.
	Zip string `json:"zip,required"`
	// Phone number of the recipient.
	Phone string `json:"phone"`
	// Province or state of the address.
	Province string `json:"province"`
	// Apartment, suite, etc. of the address.
	Street2 string      `json:"street2"`
	JSON    addressJSON `json:"-"`
}

Physical address associated with a Terminal shop user.

func (*Address) UnmarshalJSON

func (r *Address) UnmarshalJSON(data []byte) (err error)

type AddressDeleteResponse

type AddressDeleteResponse struct {
	Data AddressDeleteResponseData `json:"data,required"`
	JSON addressDeleteResponseJSON `json:"-"`
}

func (*AddressDeleteResponse) UnmarshalJSON

func (r *AddressDeleteResponse) UnmarshalJSON(data []byte) (err error)

type AddressDeleteResponseData

type AddressDeleteResponseData string
const (
	AddressDeleteResponseDataOk AddressDeleteResponseData = "ok"
)

func (AddressDeleteResponseData) IsKnown

func (r AddressDeleteResponseData) IsKnown() bool

type AddressListResponse

type AddressListResponse struct {
	// Shipping addresses.
	Data []Address               `json:"data,required"`
	JSON addressListResponseJSON `json:"-"`
}

func (*AddressListResponse) UnmarshalJSON

func (r *AddressListResponse) UnmarshalJSON(data []byte) (err error)

type AddressNewParams

type AddressNewParams struct {
	// City of the address.
	City param.Field[string] `json:"city,required"`
	// ISO 3166-1 alpha-2 country code of the address.
	Country param.Field[string] `json:"country,required"`
	// The recipient's name.
	Name param.Field[string] `json:"name,required"`
	// Street of the address.
	Street1 param.Field[string] `json:"street1,required"`
	// Zip code of the address.
	Zip param.Field[string] `json:"zip,required"`
	// Phone number of the recipient.
	Phone param.Field[string] `json:"phone"`
	// Province or state of the address.
	Province param.Field[string] `json:"province"`
	// Apartment, suite, etc. of the address.
	Street2 param.Field[string] `json:"street2"`
}

func (AddressNewParams) MarshalJSON

func (r AddressNewParams) MarshalJSON() (data []byte, err error)

type AddressNewResponse

type AddressNewResponse struct {
	// Shipping address ID.
	Data string                 `json:"data,required"`
	JSON addressNewResponseJSON `json:"-"`
}

func (*AddressNewResponse) UnmarshalJSON

func (r *AddressNewResponse) UnmarshalJSON(data []byte) (err error)

type AddressService

type AddressService struct {
	Options []option.RequestOption
}

AddressService contains methods and other services that help with interacting with the terminal API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewAddressService method instead.

func NewAddressService

func NewAddressService(opts ...option.RequestOption) (r *AddressService)

NewAddressService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*AddressService) Delete

func (r *AddressService) Delete(ctx context.Context, id string, opts ...option.RequestOption) (res *AddressDeleteResponse, err error)

Delete a shipping address from the current user.

func (*AddressService) List

func (r *AddressService) List(ctx context.Context, opts ...option.RequestOption) (res *AddressListResponse, err error)

Get the shipping addresses associated with the current user.

func (*AddressService) New

Create and add a shipping address to the current user.

type Card

type Card struct {
	// Unique object identifier. The format and length of IDs may change over time.
	ID string `json:"id,required"`
	// Brand of the card.
	Brand string `json:"brand,required"`
	// Expiration of the card.
	Expiration CardExpiration `json:"expiration,required"`
	// Last four digits of the card.
	Last4 string   `json:"last4,required"`
	JSON  cardJSON `json:"-"`
}

Credit card used for payments in the Terminal shop.

func (*Card) UnmarshalJSON

func (r *Card) UnmarshalJSON(data []byte) (err error)

type CardDeleteResponse

type CardDeleteResponse struct {
	Data CardDeleteResponseData `json:"data,required"`
	JSON cardDeleteResponseJSON `json:"-"`
}

func (*CardDeleteResponse) UnmarshalJSON

func (r *CardDeleteResponse) UnmarshalJSON(data []byte) (err error)

type CardDeleteResponseData

type CardDeleteResponseData string
const (
	CardDeleteResponseDataOk CardDeleteResponseData = "ok"
)

func (CardDeleteResponseData) IsKnown

func (r CardDeleteResponseData) IsKnown() bool

type CardExpiration

type CardExpiration struct {
	// Expiration month of the card.
	Month int64 `json:"month,required"`
	// Expiration year of the card.
	Year int64              `json:"year,required"`
	JSON cardExpirationJSON `json:"-"`
}

Expiration of the card.

func (*CardExpiration) UnmarshalJSON

func (r *CardExpiration) UnmarshalJSON(data []byte) (err error)

type CardListResponse

type CardListResponse struct {
	// List of cards associated with the user.
	Data []Card               `json:"data,required"`
	JSON cardListResponseJSON `json:"-"`
}

func (*CardListResponse) UnmarshalJSON

func (r *CardListResponse) UnmarshalJSON(data []byte) (err error)

type CardNewParams

type CardNewParams struct {
	// Stripe card token. Learn how to
	// [create one here](https://docs.stripe.com/api/tokens/create_card).
	Token param.Field[string] `json:"token,required"`
}

func (CardNewParams) MarshalJSON

func (r CardNewParams) MarshalJSON() (data []byte, err error)

type CardNewResponse

type CardNewResponse struct {
	// ID of the card.
	Data string              `json:"data,required"`
	JSON cardNewResponseJSON `json:"-"`
}

func (*CardNewResponse) UnmarshalJSON

func (r *CardNewResponse) UnmarshalJSON(data []byte) (err error)

type CardService

type CardService struct {
	Options []option.RequestOption
}

CardService contains methods and other services that help with interacting with the terminal API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewCardService method instead.

func NewCardService

func NewCardService(opts ...option.RequestOption) (r *CardService)

NewCardService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*CardService) Delete

func (r *CardService) Delete(ctx context.Context, id string, opts ...option.RequestOption) (res *CardDeleteResponse, err error)

Delete a credit card associated with the current user.

func (*CardService) List

func (r *CardService) List(ctx context.Context, opts ...option.RequestOption) (res *CardListResponse, err error)

List the credit cards associated with the current user.

func (*CardService) New

func (r *CardService) New(ctx context.Context, body CardNewParams, opts ...option.RequestOption) (res *CardNewResponse, err error)

Attach a credit card (tokenized via Stripe) to the current user.

type Cart

type Cart struct {
	// The subtotal and shipping amounts for the current user's cart.
	Amount CartAmount `json:"amount,required"`
	// An array of items in the current user's cart.
	Items []CartItem `json:"items,required"`
	// The subtotal of all items in the current user's cart, in cents (USD).
	Subtotal int64 `json:"subtotal,required"`
	// ID of the shipping address selected on the current user's cart.
	AddressID string `json:"addressID"`
	// ID of the card selected on the current user's cart.
	CardID string `json:"cardID"`
	// Shipping information for the current user's cart.
	Shipping CartShipping `json:"shipping"`
	JSON     cartJSON     `json:"-"`
}

The current Terminal shop user's cart.

func (*Cart) UnmarshalJSON

func (r *Cart) UnmarshalJSON(data []byte) (err error)

type CartAmount

type CartAmount struct {
	// Subtotal of the current user's cart, in cents (USD).
	Subtotal int64 `json:"subtotal,required"`
	// Shipping amount of the current user's cart, in cents (USD).
	Shipping int64          `json:"shipping"`
	JSON     cartAmountJSON `json:"-"`
}

The subtotal and shipping amounts for the current user's cart.

func (*CartAmount) UnmarshalJSON

func (r *CartAmount) UnmarshalJSON(data []byte) (err error)

type CartItem

type CartItem struct {
	// Unique object identifier. The format and length of IDs may change over time.
	ID string `json:"id,required"`
	// ID of the product variant for this item in the current user's cart.
	ProductVariantID string `json:"productVariantID,required"`
	// Quantity of the item in the current user's cart.
	Quantity int64 `json:"quantity,required"`
	// Subtotal of the item in the current user's cart, in cents (USD).
	Subtotal int64        `json:"subtotal,required"`
	JSON     cartItemJSON `json:"-"`
}

An item in the current Terminal shop user's cart.

func (*CartItem) UnmarshalJSON

func (r *CartItem) UnmarshalJSON(data []byte) (err error)

type CartListResponse

type CartListResponse struct {
	// The current Terminal shop user's cart.
	Data Cart                 `json:"data,required"`
	JSON cartListResponseJSON `json:"-"`
}

func (*CartListResponse) UnmarshalJSON

func (r *CartListResponse) UnmarshalJSON(data []byte) (err error)

type CartService

type CartService struct {
	Options []option.RequestOption
}

CartService contains methods and other services that help with interacting with the terminal API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewCartService method instead.

func NewCartService

func NewCartService(opts ...option.RequestOption) (r *CartService)

NewCartService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*CartService) List

func (r *CartService) List(ctx context.Context, opts ...option.RequestOption) (res *CartListResponse, err error)

Get the current user's cart.

func (*CartService) SetAddress

func (r *CartService) SetAddress(ctx context.Context, body CartSetAddressParams, opts ...option.RequestOption) (res *CartSetAddressResponse, err error)

Set the shipping address for the current user's cart.

func (*CartService) SetCard

func (r *CartService) SetCard(ctx context.Context, body CartSetCardParams, opts ...option.RequestOption) (res *CartSetCardResponse, err error)

Set the credit card for the current user's cart.

func (*CartService) SetItem

func (r *CartService) SetItem(ctx context.Context, body CartSetItemParams, opts ...option.RequestOption) (res *CartSetItemResponse, err error)

Add an item to the current user's cart.

type CartSetAddressParams

type CartSetAddressParams struct {
	// ID of the shipping address to set for the current user's cart.
	AddressID param.Field[string] `json:"addressID,required"`
}

func (CartSetAddressParams) MarshalJSON

func (r CartSetAddressParams) MarshalJSON() (data []byte, err error)

type CartSetAddressResponse

type CartSetAddressResponse struct {
	Data CartSetAddressResponseData `json:"data,required"`
	JSON cartSetAddressResponseJSON `json:"-"`
}

func (*CartSetAddressResponse) UnmarshalJSON

func (r *CartSetAddressResponse) UnmarshalJSON(data []byte) (err error)

type CartSetAddressResponseData

type CartSetAddressResponseData string
const (
	CartSetAddressResponseDataOk CartSetAddressResponseData = "ok"
)

func (CartSetAddressResponseData) IsKnown

func (r CartSetAddressResponseData) IsKnown() bool

type CartSetCardParams

type CartSetCardParams struct {
	// ID of the credit card to set for the current user's cart.
	CardID param.Field[string] `json:"cardID,required"`
}

func (CartSetCardParams) MarshalJSON

func (r CartSetCardParams) MarshalJSON() (data []byte, err error)

type CartSetCardResponse

type CartSetCardResponse struct {
	Data CartSetCardResponseData `json:"data,required"`
	JSON cartSetCardResponseJSON `json:"-"`
}

func (*CartSetCardResponse) UnmarshalJSON

func (r *CartSetCardResponse) UnmarshalJSON(data []byte) (err error)

type CartSetCardResponseData

type CartSetCardResponseData string
const (
	CartSetCardResponseDataOk CartSetCardResponseData = "ok"
)

func (CartSetCardResponseData) IsKnown

func (r CartSetCardResponseData) IsKnown() bool

type CartSetItemParams

type CartSetItemParams struct {
	// ID of the product variant to add to the cart.
	ProductVariantID param.Field[string] `json:"productVariantID,required"`
	// Quantity of the item to add to the cart.
	Quantity param.Field[int64] `json:"quantity,required"`
}

func (CartSetItemParams) MarshalJSON

func (r CartSetItemParams) MarshalJSON() (data []byte, err error)

type CartSetItemResponse

type CartSetItemResponse struct {
	// The current Terminal shop user's cart.
	Data Cart                    `json:"data,required"`
	JSON cartSetItemResponseJSON `json:"-"`
}

func (*CartSetItemResponse) UnmarshalJSON

func (r *CartSetItemResponse) UnmarshalJSON(data []byte) (err error)

type CartShipping

type CartShipping struct {
	// Shipping service name.
	Service string `json:"service"`
	// Shipping timeframe provided by the shipping carrier.
	Timeframe string           `json:"timeframe"`
	JSON      cartShippingJSON `json:"-"`
}

Shipping information for the current user's cart.

func (*CartShipping) UnmarshalJSON

func (r *CartShipping) UnmarshalJSON(data []byte) (err error)

type Client

type Client struct {
	Options       []option.RequestOption
	Products      *ProductService
	Users         *UserService
	Addresses     *AddressService
	Cards         *CardService
	Cart          *CartService
	Orders        *OrderService
	Subscriptions *SubscriptionService
	Emails        *EmailService
}

Client creates a struct with services and top level methods that help with interacting with the terminal API. You should not instantiate this client directly, and instead use the NewClient method instead.

func NewClient

func NewClient(opts ...option.RequestOption) (r *Client)

NewClient generates a new client with the default option read from the environment (TERMINAL_BEARER_TOKEN). The option passed in as arguments are applied after these default arguments, and all option will be passed down to the services and requests that this client makes.

func (*Client) Delete

func (r *Client) Delete(ctx context.Context, path string, params interface{}, res interface{}, opts ...option.RequestOption) error

Delete makes a DELETE request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Execute

func (r *Client) Execute(ctx context.Context, method string, path string, params interface{}, res interface{}, opts ...option.RequestOption) error

Execute makes a request with the given context, method, URL, request params, response, and request options. This is useful for hitting undocumented endpoints while retaining the base URL, auth, retries, and other options from the client.

If a byte slice or an io.Reader is supplied to params, it will be used as-is for the request body.

The params is by default serialized into the body using encoding/json. If your type implements a MarshalJSON function, it will be used instead to serialize the request. If a URLQuery method is implemented, the returned [url.Values] will be used as query strings to the url.

If your params struct uses param.Field, you must provide either [MarshalJSON], [URLQuery], and/or [MarshalForm] functions. It is undefined behavior to use a struct uses param.Field without specifying how it is serialized.

Any "…Params" object defined in this library can be used as the request argument. Note that 'path' arguments will not be forwarded into the url.

The response body will be deserialized into the res variable, depending on its type:

  • A pointer to a *http.Response is populated by the raw response.
  • A pointer to a byte array will be populated with the contents of the request body.
  • A pointer to any other type uses this library's default JSON decoding, which respects UnmarshalJSON if it is defined on the type.
  • A nil value will not read the response body.

For even greater flexibility, see option.WithResponseInto and option.WithResponseBodyInto.

func (*Client) Get

func (r *Client) Get(ctx context.Context, path string, params interface{}, res interface{}, opts ...option.RequestOption) error

Get makes a GET request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Patch

func (r *Client) Patch(ctx context.Context, path string, params interface{}, res interface{}, opts ...option.RequestOption) error

Patch makes a PATCH request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Post

func (r *Client) Post(ctx context.Context, path string, params interface{}, res interface{}, opts ...option.RequestOption) error

Post makes a POST request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Put

func (r *Client) Put(ctx context.Context, path string, params interface{}, res interface{}, opts ...option.RequestOption) error

Put makes a PUT request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

type EmailNewParams

type EmailNewParams struct {
	// Email address to subscribe to Terminal updates with.
	Email param.Field[string] `json:"email,required" format:"email"`
}

func (EmailNewParams) MarshalJSON

func (r EmailNewParams) MarshalJSON() (data []byte, err error)

type EmailNewResponse

type EmailNewResponse struct {
	Data EmailNewResponseData `json:"data,required"`
	JSON emailNewResponseJSON `json:"-"`
}

func (*EmailNewResponse) UnmarshalJSON

func (r *EmailNewResponse) UnmarshalJSON(data []byte) (err error)

type EmailNewResponseData

type EmailNewResponseData string
const (
	EmailNewResponseDataOk EmailNewResponseData = "ok"
)

func (EmailNewResponseData) IsKnown

func (r EmailNewResponseData) IsKnown() bool

type EmailService

type EmailService struct {
	Options []option.RequestOption
}

EmailService contains methods and other services that help with interacting with the terminal API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewEmailService method instead.

func NewEmailService

func NewEmailService(opts ...option.RequestOption) (r *EmailService)

NewEmailService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*EmailService) New

func (r *EmailService) New(ctx context.Context, body EmailNewParams, opts ...option.RequestOption) (res *EmailNewResponse, err error)

Subscribe to email updates from Terminal.

type Error

type Error = apierror.Error

type Order

type Order struct {
	// Unique object identifier. The format and length of IDs may change over time.
	ID string `json:"id,required"`
	// The subtotal and shipping amounts of the order.
	Amount OrderAmount `json:"amount,required"`
	// Items in the order.
	Items []OrderItem `json:"items,required"`
	// Shipping address of the order.
	Shipping OrderShipping `json:"shipping,required"`
	// Tracking information of the order.
	Tracking OrderTracking `json:"tracking,required"`
	// Zero-based index of the order for this user only.
	Index int64     `json:"index"`
	JSON  orderJSON `json:"-"`
}

An order from the Terminal shop.

func (*Order) UnmarshalJSON

func (r *Order) UnmarshalJSON(data []byte) (err error)

type OrderAmount

type OrderAmount struct {
	// Shipping amount of the order, in cents (USD).
	Shipping int64 `json:"shipping,required"`
	// Subtotal amount of the order, in cents (USD).
	Subtotal int64           `json:"subtotal,required"`
	JSON     orderAmountJSON `json:"-"`
}

The subtotal and shipping amounts of the order.

func (*OrderAmount) UnmarshalJSON

func (r *OrderAmount) UnmarshalJSON(data []byte) (err error)

type OrderGetResponse

type OrderGetResponse struct {
	// An order from the Terminal shop.
	Data Order                `json:"data,required"`
	JSON orderGetResponseJSON `json:"-"`
}

func (*OrderGetResponse) UnmarshalJSON

func (r *OrderGetResponse) UnmarshalJSON(data []byte) (err error)

type OrderItem

type OrderItem struct {
	// Unique object identifier. The format and length of IDs may change over time.
	ID string `json:"id,required"`
	// Amount of the item in the order, in cents (USD).
	Amount int64 `json:"amount,required"`
	// Quantity of the item in the order.
	Quantity int64 `json:"quantity,required"`
	// Description of the item in the order.
	Description string `json:"description"`
	// ID of the product variant of the item in the order.
	ProductVariantID string        `json:"productVariantID"`
	JSON             orderItemJSON `json:"-"`
}

func (*OrderItem) UnmarshalJSON

func (r *OrderItem) UnmarshalJSON(data []byte) (err error)

type OrderListResponse

type OrderListResponse struct {
	// List of orders.
	Data []Order               `json:"data,required"`
	JSON orderListResponseJSON `json:"-"`
}

func (*OrderListResponse) UnmarshalJSON

func (r *OrderListResponse) UnmarshalJSON(data []byte) (err error)

type OrderNewResponse

type OrderNewResponse struct {
	// An order from the Terminal shop.
	Data Order                `json:"data,required"`
	JSON orderNewResponseJSON `json:"-"`
}

func (*OrderNewResponse) UnmarshalJSON

func (r *OrderNewResponse) UnmarshalJSON(data []byte) (err error)

type OrderService

type OrderService struct {
	Options []option.RequestOption
}

OrderService contains methods and other services that help with interacting with the terminal API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewOrderService method instead.

func NewOrderService

func NewOrderService(opts ...option.RequestOption) (r *OrderService)

NewOrderService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*OrderService) Get

func (r *OrderService) Get(ctx context.Context, id string, opts ...option.RequestOption) (res *OrderGetResponse, err error)

Get the order with the given ID.

func (*OrderService) List

func (r *OrderService) List(ctx context.Context, opts ...option.RequestOption) (res *OrderListResponse, err error)

List the orders associated with the current user.

func (*OrderService) New

func (r *OrderService) New(ctx context.Context, opts ...option.RequestOption) (res *OrderNewResponse, err error)

Create an order from the current user's cart.

type OrderShipping

type OrderShipping struct {
	// City of the address.
	City string `json:"city,required"`
	// ISO 3166-1 alpha-2 country code of the address.
	Country string `json:"country,required"`
	// The recipient's name.
	Name string `json:"name,required"`
	// Street of the address.
	Street1 string `json:"street1,required"`
	// Zip code of the address.
	Zip string `json:"zip,required"`
	// Phone number of the recipient.
	Phone string `json:"phone"`
	// Province or state of the address.
	Province string `json:"province"`
	// Apartment, suite, etc. of the address.
	Street2 string            `json:"street2"`
	JSON    orderShippingJSON `json:"-"`
}

Shipping address of the order.

func (*OrderShipping) UnmarshalJSON

func (r *OrderShipping) UnmarshalJSON(data []byte) (err error)

type OrderTracking

type OrderTracking struct {
	// Tracking number of the order.
	Number string `json:"number"`
	// Shipping service of the order.
	Service string `json:"service"`
	// Tracking URL of the order.
	URL  string            `json:"url"`
	JSON orderTrackingJSON `json:"-"`
}

Tracking information of the order.

func (*OrderTracking) UnmarshalJSON

func (r *OrderTracking) UnmarshalJSON(data []byte) (err error)

type Product

type Product struct {
	// Unique object identifier. The format and length of IDs may change over time.
	ID string `json:"id,required"`
	// Description of the product.
	Description string `json:"description,required"`
	// Name of the product.
	Name string `json:"name,required"`
	// List of variants of the product.
	Variants []ProductVariant `json:"variants,required"`
	// Order of the product used when displaying a sorted list of products.
	Order int64 `json:"order"`
	// Whether the product must be or can be subscribed to.
	Subscription ProductSubscription `json:"subscription"`
	// Tags for the product.
	Tags map[string]string `json:"tags"`
	JSON productJSON       `json:"-"`
}

Product sold in the Terminal shop.

func (*Product) UnmarshalJSON

func (r *Product) UnmarshalJSON(data []byte) (err error)

type ProductListResponse

type ProductListResponse struct {
	// A list of products.
	Data []Product               `json:"data,required"`
	JSON productListResponseJSON `json:"-"`
}

func (*ProductListResponse) UnmarshalJSON

func (r *ProductListResponse) UnmarshalJSON(data []byte) (err error)

type ProductService

type ProductService struct {
	Options []option.RequestOption
}

ProductService contains methods and other services that help with interacting with the terminal API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewProductService method instead.

func NewProductService

func NewProductService(opts ...option.RequestOption) (r *ProductService)

NewProductService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*ProductService) List

func (r *ProductService) List(ctx context.Context, opts ...option.RequestOption) (res *ProductListResponse, err error)

List all products for sale in the Terminal shop.

type ProductSubscription

type ProductSubscription string

Whether the product must be or can be subscribed to.

const (
	ProductSubscriptionAllowed  ProductSubscription = "allowed"
	ProductSubscriptionRequired ProductSubscription = "required"
)

func (ProductSubscription) IsKnown

func (r ProductSubscription) IsKnown() bool

type ProductVariant

type ProductVariant struct {
	// Unique object identifier. The format and length of IDs may change over time.
	ID string `json:"id,required"`
	// Name of the product variant.
	Name string `json:"name,required"`
	// Price of the product variant in cents (USD).
	Price int64              `json:"price,required"`
	JSON  productVariantJSON `json:"-"`
}

Variant of a product in the Terminal shop.

func (*ProductVariant) UnmarshalJSON

func (r *ProductVariant) UnmarshalJSON(data []byte) (err error)

type Subscription

type Subscription struct {
	// Unique object identifier. The format and length of IDs may change over time.
	ID string `json:"id,required"`
	// ID of the shipping address used for the subscription.
	AddressID string `json:"addressID,required"`
	// ID of the card used for the subscription.
	CardID string `json:"cardID,required"`
	// Frequency of the subscription.
	Frequency SubscriptionFrequency `json:"frequency,required"`
	// ID of the product variant being subscribed to.
	ProductVariantID string `json:"productVariantID,required"`
	// Quantity of the subscription.
	Quantity int64            `json:"quantity,required"`
	JSON     subscriptionJSON `json:"-"`
}

Subscription to a Terminal shop product.

func (*Subscription) UnmarshalJSON

func (r *Subscription) UnmarshalJSON(data []byte) (err error)

type SubscriptionDeleteResponse

type SubscriptionDeleteResponse struct {
	Data SubscriptionDeleteResponseData `json:"data,required"`
	JSON subscriptionDeleteResponseJSON `json:"-"`
}

func (*SubscriptionDeleteResponse) UnmarshalJSON

func (r *SubscriptionDeleteResponse) UnmarshalJSON(data []byte) (err error)

type SubscriptionDeleteResponseData

type SubscriptionDeleteResponseData string
const (
	SubscriptionDeleteResponseDataOk SubscriptionDeleteResponseData = "ok"
)

func (SubscriptionDeleteResponseData) IsKnown

type SubscriptionFrequency

type SubscriptionFrequency string

Frequency of the subscription.

const (
	SubscriptionFrequencyFixed   SubscriptionFrequency = "fixed"
	SubscriptionFrequencyDaily   SubscriptionFrequency = "daily"
	SubscriptionFrequencyWeekly  SubscriptionFrequency = "weekly"
	SubscriptionFrequencyMonthly SubscriptionFrequency = "monthly"
	SubscriptionFrequencyYearly  SubscriptionFrequency = "yearly"
)

func (SubscriptionFrequency) IsKnown

func (r SubscriptionFrequency) IsKnown() bool

type SubscriptionListResponse

type SubscriptionListResponse struct {
	// List of subscriptions.
	Data []Subscription               `json:"data,required"`
	JSON subscriptionListResponseJSON `json:"-"`
}

func (*SubscriptionListResponse) UnmarshalJSON

func (r *SubscriptionListResponse) UnmarshalJSON(data []byte) (err error)

type SubscriptionNewParams

type SubscriptionNewParams struct {
	// Subscription to a Terminal shop product.
	Subscription SubscriptionParam `json:"subscription,required"`
}

func (SubscriptionNewParams) MarshalJSON

func (r SubscriptionNewParams) MarshalJSON() (data []byte, err error)

type SubscriptionNewResponse

type SubscriptionNewResponse struct {
	Data SubscriptionNewResponseData `json:"data,required"`
	JSON subscriptionNewResponseJSON `json:"-"`
}

func (*SubscriptionNewResponse) UnmarshalJSON

func (r *SubscriptionNewResponse) UnmarshalJSON(data []byte) (err error)

type SubscriptionNewResponseData

type SubscriptionNewResponseData string
const (
	SubscriptionNewResponseDataOk SubscriptionNewResponseData = "ok"
)

func (SubscriptionNewResponseData) IsKnown

func (r SubscriptionNewResponseData) IsKnown() bool

type SubscriptionParam

type SubscriptionParam struct {
	// Unique object identifier. The format and length of IDs may change over time.
	ID param.Field[string] `json:"id,required"`
	// ID of the shipping address used for the subscription.
	AddressID param.Field[string] `json:"addressID,required"`
	// ID of the card used for the subscription.
	CardID param.Field[string] `json:"cardID,required"`
	// Frequency of the subscription.
	Frequency param.Field[SubscriptionFrequency] `json:"frequency,required"`
	// ID of the product variant being subscribed to.
	ProductVariantID param.Field[string] `json:"productVariantID,required"`
	// Quantity of the subscription.
	Quantity param.Field[int64] `json:"quantity,required"`
}

Subscription to a Terminal shop product.

func (SubscriptionParam) MarshalJSON

func (r SubscriptionParam) MarshalJSON() (data []byte, err error)

type SubscriptionService

type SubscriptionService struct {
	Options []option.RequestOption
}

SubscriptionService contains methods and other services that help with interacting with the terminal API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewSubscriptionService method instead.

func NewSubscriptionService

func NewSubscriptionService(opts ...option.RequestOption) (r *SubscriptionService)

NewSubscriptionService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*SubscriptionService) Delete

Cancel a subscription for the current user.

func (*SubscriptionService) List

List the subscriptions associated with the current user.

func (*SubscriptionService) New

Create a subscription for the current user.

type User

type User struct {
	// Unique object identifier. The format and length of IDs may change over time.
	ID string `json:"id,required"`
	// Email address of the user.
	Email string `json:"email,required,nullable"`
	// The user's fingerprint, derived from their public SSH key.
	Fingerprint string `json:"fingerprint,required,nullable"`
	// Name of the user.
	Name string `json:"name,required,nullable"`
	// Stripe customer ID of the user.
	StripeCustomerID string   `json:"stripeCustomerID,required"`
	JSON             userJSON `json:"-"`
}

A Terminal shop user. (We have users, btw.)

func (*User) UnmarshalJSON

func (r *User) UnmarshalJSON(data []byte) (err error)

type UserInitResponse

type UserInitResponse struct {
	// Initial app data.
	Data UserInitResponseData `json:"data,required"`
	JSON userInitResponseJSON `json:"-"`
}

func (*UserInitResponse) UnmarshalJSON

func (r *UserInitResponse) UnmarshalJSON(data []byte) (err error)

type UserInitResponseData

type UserInitResponseData struct {
	Addresses []Address `json:"addresses,required"`
	Cards     []Card    `json:"cards,required"`
	// The current Terminal shop user's cart.
	Cart          Cart           `json:"cart,required"`
	Orders        []Order        `json:"orders,required"`
	Products      []Product      `json:"products,required"`
	Subscriptions []Subscription `json:"subscriptions,required"`
	// A Terminal shop user. (We have users, btw.)
	User User                     `json:"user,required"`
	JSON userInitResponseDataJSON `json:"-"`
}

Initial app data.

func (*UserInitResponseData) UnmarshalJSON

func (r *UserInitResponseData) UnmarshalJSON(data []byte) (err error)

type UserMeResponse

type UserMeResponse struct {
	// A Terminal shop user. (We have users, btw.)
	Data User               `json:"data,required"`
	JSON userMeResponseJSON `json:"-"`
}

func (*UserMeResponse) UnmarshalJSON

func (r *UserMeResponse) UnmarshalJSON(data []byte) (err error)

type UserService

type UserService struct {
	Options []option.RequestOption
}

UserService contains methods and other services that help with interacting with the terminal API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewUserService method instead.

func NewUserService

func NewUserService(opts ...option.RequestOption) (r *UserService)

NewUserService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*UserService) Init

func (r *UserService) Init(ctx context.Context, opts ...option.RequestOption) (res *UserInitResponse, err error)

Get initial app data, including user, products, cart, addresses, cards, subscriptions, and orders.

func (*UserService) Me

func (r *UserService) Me(ctx context.Context, opts ...option.RequestOption) (res *UserMeResponse, err error)

Get the current user.

func (*UserService) Update

func (r *UserService) Update(ctx context.Context, body UserUpdateParams, opts ...option.RequestOption) (res *UserUpdateResponse, err error)

Update the current user.

type UserUpdateParams

type UserUpdateParams struct {
	// Email address of the user.
	Email param.Field[string] `json:"email"`
	// Name of the user.
	Name param.Field[string] `json:"name"`
}

func (UserUpdateParams) MarshalJSON

func (r UserUpdateParams) MarshalJSON() (data []byte, err error)

type UserUpdateResponse

type UserUpdateResponse struct {
	// A Terminal shop user. (We have users, btw.)
	Data User                   `json:"data,required"`
	JSON userUpdateResponseJSON `json:"-"`
}

func (*UserUpdateResponse) UnmarshalJSON

func (r *UserUpdateResponse) UnmarshalJSON(data []byte) (err error)

Directories

Path Synopsis

Jump to