terminal

package module
v0.1.0-alpha.33 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 17, 2024 License: Apache-2.0 Imports: 12 Imported by: 4

README

Terminal Go API Library

Go Reference

The Terminal Go library provides convenient access to the Terminal REST API from applications written in Go. The full API of this library can be found in api.md.

It is generated with Stainless.

Installation

import (
	"github.com/terminaldotshop/terminal-sdk-go" // imported as terminal
)

Or to pin the version:

go get -u 'github.com/terminaldotshop/terminal-sdk-go@v0.1.0-alpha.33'

Requirements

This library requires Go 1.18+.

Usage

The full API of this library can be found in api.md.

package main

import (
	"context"
	"fmt"

	"github.com/terminaldotshop/terminal-sdk-go"
	"github.com/terminaldotshop/terminal-sdk-go/option"
)

func main() {
	client := terminal.NewClient(
		option.WithBearerToken("My Bearer Token"), // defaults to os.LookupEnv("TERMINAL_BEARER_TOKEN")
		option.WithEnvironmentDev(),               // defaults to option.WithEnvironmentProduction()
	)
	product, err := client.Product.List(context.TODO())
	if err != nil {
		panic(err.Error())
	}
	fmt.Printf("%+v\n", product.Result)
}

Request fields

All request parameters are wrapped in a generic Field type, which we use to distinguish zero values from null or omitted fields.

This prevents accidentally sending a zero value if you forget a required parameter, and enables explicitly sending null, false, '', or 0 on optional parameters. Any field not specified is not sent.

To construct fields with values, use the helpers String(), Int(), Float(), or most commonly, the generic F[T](). To send a null, use Null[T](), and to send a nonconforming value, use Raw[T](any). For example:

params := FooParams{
	Name: terminal.F("hello"),

	// Explicitly send `"description": null`
	Description: terminal.Null[string](),

	Point: terminal.F(terminal.Point{
		X: terminal.Int(0),
		Y: terminal.Int(1),

		// In cases where the API specifies a given type,
		// but you want to send something else, use `Raw`:
		Z: terminal.Raw[int64](0.01), // sends a float
	}),
}
Response objects

All fields in response structs are value types (not pointers or wrappers).

If a given field is null, not present, or invalid, the corresponding field will simply be its zero value.

All response structs also include a special JSON field, containing more detailed information about each property, which you can use like so:

if res.Name == "" {
	// true if `"name"` is either not present or explicitly null
	res.JSON.Name.IsNull()

	// true if the `"name"` key was not present in the repsonse JSON at all
	res.JSON.Name.IsMissing()

	// When the API returns data that cannot be coerced to the expected type:
	if res.JSON.Name.IsInvalid() {
		raw := res.JSON.Name.Raw()

		legacyName := struct{
			First string `json:"first"`
			Last  string `json:"last"`
		}{}
		json.Unmarshal([]byte(raw), &legacyName)
		name = legacyName.First + " " + legacyName.Last
	}
}

These .JSON structs also include an Extras map containing any properties in the json response that were not specified in the struct. This can be useful for API features not yet present in the SDK.

body := res.JSON.ExtraFields["my_unexpected_field"].Raw()
RequestOptions

This library uses the functional options pattern. Functions defined in the option package return a RequestOption, which is a closure that mutates a RequestConfig. These options can be supplied to the client or at individual requests. For example:

client := terminal.NewClient(
	// Adds a header to every request made by the client
	option.WithHeader("X-Some-Header", "custom_header_info"),
)

client.Product.List(context.TODO(), ...,
	// Override the header
	option.WithHeader("X-Some-Header", "some_other_custom_header_info"),
	// Add an undocumented field to the request body, using sjson syntax
	option.WithJSONSet("some.json.path", map[string]string{"my": "object"}),
)

See the full list of request options.

Pagination

This library provides some conveniences for working with paginated list endpoints.

You can use .ListAutoPaging() methods to iterate through items across all pages:

Or you can use simple .List() methods to fetch a single page and receive a standard response object with additional helper methods like .GetNextPage(), e.g.:

Errors

When the API returns a non-success status code, we return an error with type *terminal.Error. This contains the StatusCode, *http.Request, and *http.Response values of the request, as well as the JSON of the error body (much like other response objects in the SDK).

To handle errors, we recommend that you use the errors.As pattern:

_, err := client.Product.List(context.TODO())
if err != nil {
	var apierr *terminal.Error
	if errors.As(err, &apierr) {
		println(string(apierr.DumpRequest(true)))  // Prints the serialized HTTP request
		println(string(apierr.DumpResponse(true))) // Prints the serialized HTTP response
	}
	panic(err.Error()) // GET "/product": 400 Bad Request { ... }
}

When other errors occur, they are returned unwrapped; for example, if HTTP transport fails, you might receive *url.Error wrapping *net.OpError.

Timeouts

Requests do not time out by default; use context to configure a timeout for a request lifecycle.

Note that if a request is retried, the context timeout does not start over. To set a per-retry timeout, use option.WithRequestTimeout().

// This sets the timeout for the request, including all the retries.
ctx, cancel := context.WithTimeout(context.Background(), 5*time.Minute)
defer cancel()
client.Product.List(
	ctx,
	// This sets the per-retry timeout
	option.WithRequestTimeout(20*time.Second),
)
File uploads

Request parameters that correspond to file uploads in multipart requests are typed as param.Field[io.Reader]. The contents of the io.Reader will by default be sent as a multipart form part with the file name of "anonymous_file" and content-type of "application/octet-stream".

The file name and content-type can be customized by implementing Name() string or ContentType() string on the run-time type of io.Reader. Note that os.File implements Name() string, so a file returned by os.Open will be sent with the file name on disk.

We also provide a helper terminal.FileParam(reader io.Reader, filename string, contentType string) which can be used to wrap any io.Reader with the appropriate file name and content type.

Retries

Certain errors will be automatically retried 2 times by default, with a short exponential backoff. We retry by default all connection errors, 408 Request Timeout, 409 Conflict, 429 Rate Limit, and >=500 Internal errors.

You can use the WithMaxRetries option to configure or disable this:

// Configure the default for all requests:
client := terminal.NewClient(
	option.WithMaxRetries(0), // default is 2
)

// Override per-request:
client.Product.List(context.TODO(), option.WithMaxRetries(5))
Making custom/undocumented requests

This library is typed for convenient access to the documented API. If you need to access undocumented endpoints, params, or response properties, the library can still be used.

Undocumented endpoints

To make requests to undocumented endpoints, you can use client.Get, client.Post, and other HTTP verbs. RequestOptions on the client, such as retries, will be respected when making these requests.

var (
    // params can be an io.Reader, a []byte, an encoding/json serializable object,
    // or a "…Params" struct defined in this library.
    params map[string]interface{}

    // result can be an []byte, *http.Response, a encoding/json deserializable object,
    // or a model defined in this library.
    result *http.Response
)
err := client.Post(context.Background(), "/unspecified", params, &result)
if err != nil {
    …
}
Undocumented request params

To make requests using undocumented parameters, you may use either the option.WithQuerySet() or the option.WithJSONSet() methods.

params := FooNewParams{
    ID:   terminal.F("id_xxxx"),
    Data: terminal.F(FooNewParamsData{
        FirstName: terminal.F("John"),
    }),
}
client.Foo.New(context.Background(), params, option.WithJSONSet("data.last_name", "Doe"))
Undocumented response properties

To access undocumented response properties, you may either access the raw JSON of the response as a string with result.JSON.RawJSON(), or get the raw JSON of a particular field on the result with result.JSON.Foo.Raw().

Any fields that are not present on the response struct will be saved and can be accessed by result.JSON.ExtraFields() which returns the extra fields as a map[string]Field.

Middleware

We provide option.WithMiddleware which applies the given middleware to requests.

func Logger(req *http.Request, next option.MiddlewareNext) (res *http.Response, err error) {
	// Before the request
	start := time.Now()
	LogReq(req)

	// Forward the request to the next handler
	res, err = next(req)

	// Handle stuff after the request
	end := time.Now()
	LogRes(res, err, start - end)

    return res, err
}

client := terminal.NewClient(
	option.WithMiddleware(Logger),
)

When multiple middlewares are provided as variadic arguments, the middlewares are applied left to right. If option.WithMiddleware is given multiple times, for example first in the client then the method, the middleware in the client will run first and the middleware given in the method will run next.

You may also replace the default http.Client with option.WithHTTPClient(client). Only one http client is accepted (this overwrites any previous client) and receives requests after any middleware has been applied.

Semantic versioning

This package generally follows SemVer conventions, though certain backwards-incompatible changes may be released as minor versions:

  1. Changes to library internals which are technically public but not intended or documented for external use. (Please open a GitHub issue to let us know if you are relying on such internals).
  2. Changes that we do not expect to impact the vast majority of users in practice.

We take backwards-compatibility seriously and work hard to ensure you can rely on a smooth upgrade experience.

We are keen for your feedback; please open an issue with questions, bugs, or suggestions.

Contributing

See the contributing documentation.

Documentation

Index

Constants

const ProductSubscriptionAllowed = shared.ProductSubscriptionAllowed

This is an alias to an internal value.

const ProductSubscriptionRequired = shared.ProductSubscriptionRequired

This is an alias to an internal value.

const SubscriptionFrequencyDaily = shared.SubscriptionFrequencyDaily

This is an alias to an internal value.

const SubscriptionFrequencyFixed = shared.SubscriptionFrequencyFixed

This is an alias to an internal value.

const SubscriptionFrequencyMonthly = shared.SubscriptionFrequencyMonthly

This is an alias to an internal value.

const SubscriptionFrequencyWeekly = shared.SubscriptionFrequencyWeekly

This is an alias to an internal value.

const SubscriptionFrequencyYearly = shared.SubscriptionFrequencyYearly

This is an alias to an internal value.

Variables

This section is empty.

Functions

func Bool

func Bool(value bool) param.Field[bool]

Bool is a param field helper which helps specify bools.

func F

func F[T any](value T) param.Field[T]

F is a param field helper used to initialize a param.Field generic struct. This helps specify null, zero values, and overrides, as well as normal values. You can read more about this in our README.

func FileParam

func FileParam(reader io.Reader, filename string, contentType string) param.Field[io.Reader]

FileParam is a param field helper which helps files with a mime content-type.

func Float

func Float(value float64) param.Field[float64]

Float is a param field helper which helps specify floats.

func Int

func Int(value int64) param.Field[int64]

Int is a param field helper which helps specify integers. This is particularly helpful when specifying integer constants for fields.

func Null

func Null[T any]() param.Field[T]

Null is a param field helper which explicitly sends null to the API.

func Raw

func Raw[T any](value any) param.Field[T]

Raw is a param field helper for specifying values for fields when the type you are looking to send is different from the type that is specified in the SDK. For example, if the type of the field is an integer, but you want to send a float, you could do that by setting the corresponding field with Raw[int](0.5).

func String

func String(value string) param.Field[string]

String is a param field helper which helps specify strings.

Types

type Address

type Address = shared.Address

This is an alias to an internal type.

type Card

type Card = shared.Card

This is an alias to an internal type.

type CardDeleteResponse

type CardDeleteResponse struct {
	Result CardDeleteResponseResult `json:"result,required"`
	JSON   cardDeleteResponseJSON   `json:"-"`
}

func (*CardDeleteResponse) UnmarshalJSON

func (r *CardDeleteResponse) UnmarshalJSON(data []byte) (err error)

type CardDeleteResponseResult

type CardDeleteResponseResult string
const (
	CardDeleteResponseResultOk CardDeleteResponseResult = "ok"
)

func (CardDeleteResponseResult) IsKnown

func (r CardDeleteResponseResult) IsKnown() bool

type CardExpiration

type CardExpiration = shared.CardExpiration

This is an alias to an internal type.

type CardListResponse

type CardListResponse struct {
	Result []shared.Card        `json:"result,required"`
	JSON   cardListResponseJSON `json:"-"`
}

func (*CardListResponse) UnmarshalJSON

func (r *CardListResponse) UnmarshalJSON(data []byte) (err error)

type CardNewParams

type CardNewParams struct {
	Token param.Field[string] `json:"token,required"`
}

func (CardNewParams) MarshalJSON

func (r CardNewParams) MarshalJSON() (data []byte, err error)

type CardNewResponse

type CardNewResponse struct {
	Result string              `json:"result,required"`
	JSON   cardNewResponseJSON `json:"-"`
}

func (*CardNewResponse) UnmarshalJSON

func (r *CardNewResponse) UnmarshalJSON(data []byte) (err error)

type CardService

type CardService struct {
	Options []option.RequestOption
}

CardService contains methods and other services that help with interacting with the terminal API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewCardService method instead.

func NewCardService

func NewCardService(opts ...option.RequestOption) (r *CardService)

NewCardService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*CardService) Delete

func (r *CardService) Delete(ctx context.Context, id string, opts ...option.RequestOption) (res *CardDeleteResponse, err error)

func (*CardService) List

func (r *CardService) List(ctx context.Context, opts ...option.RequestOption) (res *CardListResponse, err error)

func (*CardService) New

func (r *CardService) New(ctx context.Context, body CardNewParams, opts ...option.RequestOption) (res *CardNewResponse, err error)

type Cart

type Cart = shared.Cart

This is an alias to an internal type.

type CartAmount

type CartAmount = shared.CartAmount

This is an alias to an internal type.

type CartItem

type CartItem = shared.CartItem

This is an alias to an internal type.

type CartListResponse

type CartListResponse struct {
	Result shared.Cart          `json:"result,required"`
	JSON   cartListResponseJSON `json:"-"`
}

func (*CartListResponse) UnmarshalJSON

func (r *CartListResponse) UnmarshalJSON(data []byte) (err error)

type CartService

type CartService struct {
	Options []option.RequestOption
}

CartService contains methods and other services that help with interacting with the terminal API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewCartService method instead.

func NewCartService

func NewCartService(opts ...option.RequestOption) (r *CartService)

NewCartService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*CartService) List

func (r *CartService) List(ctx context.Context, opts ...option.RequestOption) (res *CartListResponse, err error)

func (*CartService) SetCard

func (r *CartService) SetCard(ctx context.Context, body CartSetCardParams, opts ...option.RequestOption) (res *CartSetCardResponse, err error)

func (*CartService) SetItem

func (r *CartService) SetItem(ctx context.Context, body CartSetItemParams, opts ...option.RequestOption) (res *CartSetItemResponse, err error)

func (*CartService) SetShipping

func (r *CartService) SetShipping(ctx context.Context, body CartSetShippingParams, opts ...option.RequestOption) (res *CartSetShippingResponse, err error)

type CartSetCardParams

type CartSetCardParams struct {
	CardID param.Field[string] `json:"cardID,required"`
}

func (CartSetCardParams) MarshalJSON

func (r CartSetCardParams) MarshalJSON() (data []byte, err error)

type CartSetCardResponse

type CartSetCardResponse struct {
	Result CartSetCardResponseResult `json:"result,required"`
	JSON   cartSetCardResponseJSON   `json:"-"`
}

func (*CartSetCardResponse) UnmarshalJSON

func (r *CartSetCardResponse) UnmarshalJSON(data []byte) (err error)

type CartSetCardResponseResult

type CartSetCardResponseResult string
const (
	CartSetCardResponseResultOk CartSetCardResponseResult = "ok"
)

func (CartSetCardResponseResult) IsKnown

func (r CartSetCardResponseResult) IsKnown() bool

type CartSetItemParams

type CartSetItemParams struct {
	ProductVariantID param.Field[string] `json:"productVariantID,required"`
	Quantity         param.Field[int64]  `json:"quantity,required"`
}

func (CartSetItemParams) MarshalJSON

func (r CartSetItemParams) MarshalJSON() (data []byte, err error)

type CartSetItemResponse

type CartSetItemResponse struct {
	Result shared.Cart             `json:"result,required"`
	JSON   cartSetItemResponseJSON `json:"-"`
}

func (*CartSetItemResponse) UnmarshalJSON

func (r *CartSetItemResponse) UnmarshalJSON(data []byte) (err error)

type CartSetShippingParams

type CartSetShippingParams struct {
	ShippingID param.Field[string] `json:"shippingID,required"`
}

func (CartSetShippingParams) MarshalJSON

func (r CartSetShippingParams) MarshalJSON() (data []byte, err error)

type CartSetShippingResponse

type CartSetShippingResponse struct {
	Result CartSetShippingResponseResult `json:"result,required"`
	JSON   cartSetShippingResponseJSON   `json:"-"`
}

func (*CartSetShippingResponse) UnmarshalJSON

func (r *CartSetShippingResponse) UnmarshalJSON(data []byte) (err error)

type CartSetShippingResponseResult

type CartSetShippingResponseResult string
const (
	CartSetShippingResponseResultOk CartSetShippingResponseResult = "ok"
)

func (CartSetShippingResponseResult) IsKnown

func (r CartSetShippingResponseResult) IsKnown() bool

type CartShipping

type CartShipping = shared.CartShipping

This is an alias to an internal type.

type Client

type Client struct {
	Options      []option.RequestOption
	Product      *ProductService
	User         *UserService
	Card         *CardService
	Cart         *CartService
	Order        *OrderService
	Subscription *SubscriptionService
}

Client creates a struct with services and top level methods that help with interacting with the terminal API. You should not instantiate this client directly, and instead use the NewClient method instead.

func NewClient

func NewClient(opts ...option.RequestOption) (r *Client)

NewClient generates a new client with the default option read from the environment (TERMINAL_BEARER_TOKEN). The option passed in as arguments are applied after these default arguments, and all option will be passed down to the services and requests that this client makes.

func (*Client) Delete

func (r *Client) Delete(ctx context.Context, path string, params interface{}, res interface{}, opts ...option.RequestOption) error

Delete makes a DELETE request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Execute

func (r *Client) Execute(ctx context.Context, method string, path string, params interface{}, res interface{}, opts ...option.RequestOption) error

Execute makes a request with the given context, method, URL, request params, response, and request options. This is useful for hitting undocumented endpoints while retaining the base URL, auth, retries, and other options from the client.

If a byte slice or an io.Reader is supplied to params, it will be used as-is for the request body.

The params is by default serialized into the body using encoding/json. If your type implements a MarshalJSON function, it will be used instead to serialize the request. If a URLQuery method is implemented, the returned [url.Values] will be used as query strings to the url.

If your params struct uses param.Field, you must provide either [MarshalJSON], [URLQuery], and/or [MarshalForm] functions. It is undefined behavior to use a struct uses param.Field without specifying how it is serialized.

Any "…Params" object defined in this library can be used as the request argument. Note that 'path' arguments will not be forwarded into the url.

The response body will be deserialized into the res variable, depending on its type:

  • A pointer to a *http.Response is populated by the raw response.
  • A pointer to a byte array will be populated with the contents of the request body.
  • A pointer to any other type uses this library's default JSON decoding, which respects UnmarshalJSON if it is defined on the type.
  • A nil value will not read the response body.

For even greater flexibility, see option.WithResponseInto and option.WithResponseBodyInto.

func (*Client) Get

func (r *Client) Get(ctx context.Context, path string, params interface{}, res interface{}, opts ...option.RequestOption) error

Get makes a GET request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Patch

func (r *Client) Patch(ctx context.Context, path string, params interface{}, res interface{}, opts ...option.RequestOption) error

Patch makes a PATCH request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Post

func (r *Client) Post(ctx context.Context, path string, params interface{}, res interface{}, opts ...option.RequestOption) error

Post makes a POST request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Put

func (r *Client) Put(ctx context.Context, path string, params interface{}, res interface{}, opts ...option.RequestOption) error

Put makes a PUT request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

type Error

type Error = apierror.Error

type Order

type Order = shared.Order

This is an alias to an internal type.

type OrderAmount

type OrderAmount = shared.OrderAmount

This is an alias to an internal type.

type OrderGetResponse

type OrderGetResponse struct {
	Result shared.Order         `json:"result,required"`
	JSON   orderGetResponseJSON `json:"-"`
}

func (*OrderGetResponse) UnmarshalJSON

func (r *OrderGetResponse) UnmarshalJSON(data []byte) (err error)

type OrderItem

type OrderItem = shared.OrderItem

This is an alias to an internal type.

type OrderListResponse

type OrderListResponse struct {
	Result []shared.Order        `json:"result,required"`
	JSON   orderListResponseJSON `json:"-"`
}

func (*OrderListResponse) UnmarshalJSON

func (r *OrderListResponse) UnmarshalJSON(data []byte) (err error)

type OrderNewResponse

type OrderNewResponse struct {
	Result shared.Order         `json:"result,required"`
	JSON   orderNewResponseJSON `json:"-"`
}

func (*OrderNewResponse) UnmarshalJSON

func (r *OrderNewResponse) UnmarshalJSON(data []byte) (err error)

type OrderService

type OrderService struct {
	Options []option.RequestOption
}

OrderService contains methods and other services that help with interacting with the terminal API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewOrderService method instead.

func NewOrderService

func NewOrderService(opts ...option.RequestOption) (r *OrderService)

NewOrderService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*OrderService) Get

func (r *OrderService) Get(ctx context.Context, id string, opts ...option.RequestOption) (res *OrderGetResponse, err error)

func (*OrderService) List

func (r *OrderService) List(ctx context.Context, opts ...option.RequestOption) (res *OrderListResponse, err error)

func (*OrderService) New

func (r *OrderService) New(ctx context.Context, opts ...option.RequestOption) (res *OrderNewResponse, err error)

type OrderShipping

type OrderShipping = shared.OrderShipping

This is an alias to an internal type.

type OrderTracking

type OrderTracking = shared.OrderTracking

This is an alias to an internal type.

type Product

type Product = shared.Product

This is an alias to an internal type.

type ProductListResponse

type ProductListResponse struct {
	Result []shared.Product        `json:"result,required"`
	JSON   productListResponseJSON `json:"-"`
}

func (*ProductListResponse) UnmarshalJSON

func (r *ProductListResponse) UnmarshalJSON(data []byte) (err error)

type ProductService

type ProductService struct {
	Options []option.RequestOption
}

ProductService contains methods and other services that help with interacting with the terminal API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewProductService method instead.

func NewProductService

func NewProductService(opts ...option.RequestOption) (r *ProductService)

NewProductService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*ProductService) List

func (r *ProductService) List(ctx context.Context, opts ...option.RequestOption) (res *ProductListResponse, err error)

type ProductSubscription

type ProductSubscription = shared.ProductSubscription

This is an alias to an internal type.

type ProductVariant

type ProductVariant = shared.ProductVariant

This is an alias to an internal type.

type Shipping

type Shipping = shared.Shipping

This is an alias to an internal type.

type Subscription

type Subscription = shared.Subscription

This is an alias to an internal type.

type SubscriptionDeleteResponse

type SubscriptionDeleteResponse struct {
	Result SubscriptionDeleteResponseResult `json:"result,required"`
	JSON   subscriptionDeleteResponseJSON   `json:"-"`
}

func (*SubscriptionDeleteResponse) UnmarshalJSON

func (r *SubscriptionDeleteResponse) UnmarshalJSON(data []byte) (err error)

type SubscriptionDeleteResponseResult

type SubscriptionDeleteResponseResult string
const (
	SubscriptionDeleteResponseResultOk SubscriptionDeleteResponseResult = "ok"
)

func (SubscriptionDeleteResponseResult) IsKnown

type SubscriptionFrequency

type SubscriptionFrequency = shared.SubscriptionFrequency

This is an alias to an internal type.

type SubscriptionListResponse

type SubscriptionListResponse struct {
	Result []shared.Subscription        `json:"result,required"`
	JSON   subscriptionListResponseJSON `json:"-"`
}

func (*SubscriptionListResponse) UnmarshalJSON

func (r *SubscriptionListResponse) UnmarshalJSON(data []byte) (err error)

type SubscriptionNewParams

type SubscriptionNewParams struct {
	CardID           param.Field[string]                         `json:"cardID,required"`
	Frequency        param.Field[SubscriptionNewParamsFrequency] `json:"frequency,required"`
	ProductVariantID param.Field[string]                         `json:"productVariantID,required"`
	Quantity         param.Field[int64]                          `json:"quantity,required"`
	ShippingID       param.Field[string]                         `json:"shippingID,required"`
}

func (SubscriptionNewParams) MarshalJSON

func (r SubscriptionNewParams) MarshalJSON() (data []byte, err error)

type SubscriptionNewParamsFrequency

type SubscriptionNewParamsFrequency string
const (
	SubscriptionNewParamsFrequencyFixed   SubscriptionNewParamsFrequency = "fixed"
	SubscriptionNewParamsFrequencyDaily   SubscriptionNewParamsFrequency = "daily"
	SubscriptionNewParamsFrequencyWeekly  SubscriptionNewParamsFrequency = "weekly"
	SubscriptionNewParamsFrequencyMonthly SubscriptionNewParamsFrequency = "monthly"
	SubscriptionNewParamsFrequencyYearly  SubscriptionNewParamsFrequency = "yearly"
)

func (SubscriptionNewParamsFrequency) IsKnown

type SubscriptionNewResponse

type SubscriptionNewResponse struct {
	Result bool                        `json:"result,required"`
	JSON   subscriptionNewResponseJSON `json:"-"`
}

func (*SubscriptionNewResponse) UnmarshalJSON

func (r *SubscriptionNewResponse) UnmarshalJSON(data []byte) (err error)

type SubscriptionService

type SubscriptionService struct {
	Options []option.RequestOption
}

SubscriptionService contains methods and other services that help with interacting with the terminal API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewSubscriptionService method instead.

func NewSubscriptionService

func NewSubscriptionService(opts ...option.RequestOption) (r *SubscriptionService)

NewSubscriptionService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*SubscriptionService) Delete

func (*SubscriptionService) List

func (*SubscriptionService) New

type User

type User = shared.User

This is an alias to an internal type.

type UserMeResponse

type UserMeResponse struct {
	Result shared.User        `json:"result,required"`
	JSON   userMeResponseJSON `json:"-"`
}

func (*UserMeResponse) UnmarshalJSON

func (r *UserMeResponse) UnmarshalJSON(data []byte) (err error)

type UserService

type UserService struct {
	Options  []option.RequestOption
	Shipping *UserShippingService
}

UserService contains methods and other services that help with interacting with the terminal API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewUserService method instead.

func NewUserService

func NewUserService(opts ...option.RequestOption) (r *UserService)

NewUserService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*UserService) Me

func (r *UserService) Me(ctx context.Context, opts ...option.RequestOption) (res *UserMeResponse, err error)

func (*UserService) Update

func (r *UserService) Update(ctx context.Context, body UserUpdateParams, opts ...option.RequestOption) (res *UserUpdateResponse, err error)

type UserShippingDeleteResponse

type UserShippingDeleteResponse struct {
	Result UserShippingDeleteResponseResult `json:"result,required"`
	JSON   userShippingDeleteResponseJSON   `json:"-"`
}

func (*UserShippingDeleteResponse) UnmarshalJSON

func (r *UserShippingDeleteResponse) UnmarshalJSON(data []byte) (err error)

type UserShippingDeleteResponseResult

type UserShippingDeleteResponseResult string
const (
	UserShippingDeleteResponseResultOk UserShippingDeleteResponseResult = "ok"
)

func (UserShippingDeleteResponseResult) IsKnown

type UserShippingListResponse

type UserShippingListResponse struct {
	Result []shared.Shipping            `json:"result,required"`
	JSON   userShippingListResponseJSON `json:"-"`
}

func (*UserShippingListResponse) UnmarshalJSON

func (r *UserShippingListResponse) UnmarshalJSON(data []byte) (err error)

type UserShippingNewParams

type UserShippingNewParams struct {
	City     param.Field[string] `json:"city,required"`
	Country  param.Field[string] `json:"country,required"`
	Name     param.Field[string] `json:"name,required"`
	Street1  param.Field[string] `json:"street1,required"`
	Zip      param.Field[string] `json:"zip,required"`
	Phone    param.Field[string] `json:"phone"`
	Province param.Field[string] `json:"province"`
	Street2  param.Field[string] `json:"street2"`
}

func (UserShippingNewParams) MarshalJSON

func (r UserShippingNewParams) MarshalJSON() (data []byte, err error)

type UserShippingNewResponse

type UserShippingNewResponse struct {
	Result string                      `json:"result,required"`
	JSON   userShippingNewResponseJSON `json:"-"`
}

func (*UserShippingNewResponse) UnmarshalJSON

func (r *UserShippingNewResponse) UnmarshalJSON(data []byte) (err error)

type UserShippingService

type UserShippingService struct {
	Options []option.RequestOption
}

UserShippingService contains methods and other services that help with interacting with the terminal API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewUserShippingService method instead.

func NewUserShippingService

func NewUserShippingService(opts ...option.RequestOption) (r *UserShippingService)

NewUserShippingService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*UserShippingService) Delete

func (*UserShippingService) List

func (*UserShippingService) New

type UserUpdateParams

type UserUpdateParams struct {
	ID    param.Field[string] `json:"id,required"`
	Email param.Field[string] `json:"email"`
	Name  param.Field[string] `json:"name"`
}

func (UserUpdateParams) MarshalJSON

func (r UserUpdateParams) MarshalJSON() (data []byte, err error)

type UserUpdateResponse

type UserUpdateResponse struct {
	Result shared.User            `json:"result,required"`
	JSON   userUpdateResponseJSON `json:"-"`
}

func (*UserUpdateResponse) UnmarshalJSON

func (r *UserUpdateResponse) UnmarshalJSON(data []byte) (err error)

Directories

Path Synopsis

Jump to